==> kdevplatform-1.5.80.tar.xz: kdevplatform-1.5.80/plugins/openwith/kdevopenwith.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=document-open
Exec=blubb
Comment=This plugin allows to open files with associated external applications.
Comment[bg]=Тази приставка позволява отваряне на файлове със съответни външни програми.
Comment[bs]=Ovaj dodatak dopušta otvaranje datoteka sa povezanim eksternim aplikacijama.
Comment[ca]=Aquest connector permet obrir fitxers amb aplicacions externes associades.
Comment[ca@valencia]=Este connector permet obrir fitxers amb aplicacions externes associades.
Comment[da]=Dette plugin tillader at åbne filer med associerede eksterne applikationer.
Comment[de]=Mit diesem Modul können Dateien mit ihnen zugewiesenen externen Anwendungen gestartet werden.
Comment[el]=Αυτό το πρόσθετο επιτρέπει το άνοιγμα αρχείων με σχετικές εξωτερικές εφαρμογές
Comment[en_GB]=This plugin allows to open files with associated external applications.
Comment[es]=Este complemento permite abrir archivos con aplicaciones externas asociadas.
Comment[et]=See plugin võimaldab avada väliste rakendustega seostatud faile.
Comment[fi]=Tämä liitännäinen mahdollistaa ulkoisiin sovelluksiin liitettyjen tiedostojen avaamisen.
Comment[fr]=Ce module externe permet d'ouvrir des fichiers avec des applications externes associées.
Comment[gl]=Este complemento permite abrir ficheiros cos programas externos asociados.
Comment[hu]=Ez a bővítmény lehetővé teszi fájlok megnyitását a kapcsolódó külső alkalmazásokkal.
Comment[it]=Questa estensione permette di aprire i file con le relative applicazioni esterne.
Comment[kk]=Бұл плагині файлдарды ашуға тиісті сыртқы қолданбаларды жұмсайды.
Comment[nb]=Dette programtillegget kan åpne filer med tilknyttede eksterne programmer.
Comment[nds]=Mit dit Moduul laat sik Dateien mit towiest extern Programmen opmaken.
Comment[nl]=Deze plugin biedt het openen van bestanden met geassocieerde externe toepassingen.
Comment[pl]=Ta wtyczka pozwala na otwieranie plików, z którymi są powiązane zewnętrzne programy.
Comment[pt]=Este 'plugin' permite abrir os ficheiros com as aplicações externas associadas.
Comment[pt_BR]=Este plugin permite abrir os arquivos com os aplicativos externos associados.
Comment[ru]=Это расширение позволяет открывать файлы в связанном внешнем приложении.
Comment[sk]=Tento plugin umožňuje otvoriť súbory s asociovanými externými aplikáciami.
Comment[sl]=Vstavek omogoča odpiranje datotek v povezanih zunanjih programih.
Comment[sv]=Insticksprogrammet tillåter att öppna filer med tillhörande externa program.
Comment[tr]=Bu eklenti dosyaları ilişkilendirilmiş dış uygulamalar ile açmayı sağlar.
Comment[uk]=За допомогою цього додатка ви зможете відкривати файли у пов’язаній з ними зовнішній програмі.
Comment[x-test]=xxThis plugin allows to open files with associated external applications.xx
Comment[zh_CN]=此插件允许使用关联的外部应用程序打开文件。
Comment[zh_TW]=此外掛程式讓您可以用外部應用程式開啟檔案。
Name=Open With
Name[bg]=Отваряне с
Name[bs]=Otvori pomoću
Name[ca]=Obre amb
Name[ca@valencia]=Obri amb
Name[cs]=Otevřít pomocí
Name[da]=Åbn med
Name[de]=Öffnen mit
Name[el]=Άνοιγμα με
Name[en_GB]=Open With
Name[es]=Abrir con
Name[et]=Avamine rakendusega
Name[fi]=Avaa ohjelmalla
Name[fr]=Ouvrir avec
Name[gl]=Abrir con
Name[hu]=Megnyitás ezzel
Name[it]=Apri con
Name[ja]=アプリケーションで開く
Name[kk]=Мынамен ашу
Name[mr]=यामध्ये उघडा
Name[nb]=Åpne med
Name[nds]=Opmaken mit
Name[nl]=Openen met
Name[pl]=Otwórz za pomocą
Name[pt]=Abrir Com
Name[pt_BR]=Abrir com
Name[ru]=Открыть с помощью
Name[sk]=Otvoriť s
Name[sl]=Odpri z
Name[sv]=Öppna med
Name[tr]=Birlikte Aç
Name[ug]=بۇنىڭدا ئېچىش
Name[uk]=Відкриття у зовнішніх програмах
Name[x-test]=xxOpen Withxx
Name[zh_CN]=打开方式
Name[zh_TW]=開啟方式
GenericName=Open With
GenericName[bg]=Отваряне с
GenericName[bs]=Otvori pomoću
GenericName[ca]=Obre amb
GenericName[ca@valencia]=Obri amb
GenericName[cs]=Otevřít pomocí
GenericName[da]=Åbn med
GenericName[de]=Öffnen mit
GenericName[el]=Άνοιγμα με
GenericName[en_GB]=Open With
GenericName[es]=Abrir con
GenericName[et]=Avamine rakendusega
GenericName[fi]=Avaa ohjelmalla
GenericName[fr]=Ouvrir avec
GenericName[gl]=Abrir con
GenericName[hu]=Megnyitás ezzel
GenericName[it]=Apri con
GenericName[ja]=アプリケーションで開く
GenericName[kk]=Мынамен ашу
GenericName[mr]=यामध्ये उघडा
GenericName[nb]=Åpne med
GenericName[nds]=Opmaken mit
GenericName[nl]=Openen met
GenericName[pl]=Otwórz za pomocą
GenericName[pt]=Abrir Com
GenericName[pt_BR]=Abrir com
GenericName[ru]=Открыть с помощью
GenericName[sk]=Otvoriť s
GenericName[sl]=Odpri z
GenericName[sv]=Öppna med
GenericName[tr]=Birlikte Aç
GenericName[ug]=بۇنىڭدا ئېچىش
GenericName[uk]=Відкриття у зовнішніх програмах
GenericName[x-test]=xxOpen Withxx
GenericName[zh_CN]=打开方式
GenericName[zh_TW]=開啟方式
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevopenwith
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevopenwith
X-KDE-PluginInfo-Author=Andreas Pakulat
X-KDevelop-Interfaces=org.kdevelop.IOpenWith
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Mode=GUI

==> kdevplatform-1.5.90.tar.xz: kdevplatform-1.5.90/plugins/openwith/kdevopenwith.desktop.cmake <==
[Desktop Entry]
Type=Service
Icon=document-open
Exec=blubb
Comment=This plugin allows to open files with associated external applications.
Comment[bg]=Тази приставка позволява отваряне на файлове със съответни външни програми.
Comment[bs]=Ovaj dodatak dopušta otvaranje datoteka sa povezanim eksternim aplikacijama.
Comment[ca]=Aquest connector permet obrir fitxers amb les aplicacions externes associades.
Comment[ca@valencia]=Este connector permet obrir fitxers amb aplicacions externes associades.
Comment[da]=Dette plugin tillader at åbne filer med associerede eksterne applikationer.
Comment[de]=Mit diesem Modul können Dateien mit ihnen zugewiesenen externen Anwendungen gestartet werden.
Comment[el]=Αυτό το πρόσθετο επιτρέπει το άνοιγμα αρχείων με σχετικές εξωτερικές εφαρμογές
Comment[en_GB]=This plugin allows to open files with associated external applications.
Comment[es]=Este complemento permite abrir archivos con aplicaciones externas asociadas.
Comment[et]=See plugin võimaldab avada väliste rakendustega seostatud faile.
Comment[fi]=Tämä liitännäinen mahdollistaa ulkoisiin sovelluksiin liitettyjen tiedostojen avaamisen.
Comment[fr]=Ce module externe permet d'ouvrir des fichiers avec des applications externes associées.
Comment[gl]=Este complemento permite abrir ficheiros cos programas externos asociados.
Comment[hu]=Ez a bővítmény lehetővé teszi fájlok megnyitását a kapcsolódó külső alkalmazásokkal.
Comment[it]=Questa estensione permette di aprire i file con le relative applicazioni esterne.
Comment[kk]=Бұл плагині файлдарды ашуға тиісті сыртқы қолданбаларды жұмсайды.
Comment[nb]=Dette programtillegget kan åpne filer med tilknyttede eksterne programmer.
Comment[nds]=Mit dit Moduul laat sik Dateien mit towiest extern Programmen opmaken.
Comment[nl]=Deze plugin biedt het openen van bestanden met geassocieerde externe toepassingen.
Comment[pl]=Ta wtyczka pozwala na otwieranie plików, z którymi są powiązane zewnętrzne programy.
Comment[pt]=Este 'plugin' permite abrir os ficheiros com as aplicações externas associadas.
Comment[pt_BR]=Este plugin permite abrir os arquivos com os aplicativos externos associados.
Comment[ru]=Это расширение позволяет открывать файлы в связанном внешнем приложении.
Comment[sk]=Tento plugin umožňuje otvoriť súbory s asociovanými externými aplikáciami.
Comment[sl]=Vstavek omogoča odpiranje datotek v povezanih zunanjih programih.
Comment[sv]=Insticksprogrammet tillåter att öppna filer med tillhörande externa program.
Comment[tr]=Bu eklenti dosyaları ilişkilendirilmiş dış uygulamalar ile açmayı sağlar.
Comment[uk]=За допомогою цього додатка ви зможете відкривати файли у пов’язаній з ними зовнішній програмі.
Comment[x-test]=xxThis plugin allows to open files with associated external applications.xx
Comment[zh_CN]=此插件允许使用关联的外部应用程序打开文件。
Comment[zh_TW]=此外掛程式讓您可以用外部應用程式開啟檔案。
Name=Open With
Name[bg]=Отваряне с
Name[bs]=Otvori pomoću
Name[ca]=Obre amb
Name[ca@valencia]=Obri amb
Name[cs]=Otevřít pomocí
Name[da]=Åbn med
Name[de]=Öffnen mit
Name[el]=Άνοιγμα με
Name[en_GB]=Open With
Name[es]=Abrir con
Name[et]=Avamine rakendusega
Name[fi]=Avaa ohjelmalla
Name[fr]=Ouvrir avec
Name[gl]=Abrir con
Name[hu]=Megnyitás ezzel
Name[it]=Apri con
Name[ja]=アプリケーションで開く
Name[kk]=Мынамен ашу
Name[mr]=यामध्ये उघडा
Name[nb]=Åpne med
Name[nds]=Opmaken mit
Name[nl]=Openen met
Name[pl]=Otwórz za pomocą
Name[pt]=Abrir Com
Name[pt_BR]=Abrir com
Name[ru]=Открыть с помощью
Name[sk]=Otvoriť s
Name[sl]=Odpri z
Name[sv]=Öppna med
Name[tr]=Birlikte Aç
Name[ug]=بۇنىڭدا ئېچىش
Name[uk]=Відкриття у зовнішніх програмах
Name[x-test]=xxOpen Withxx
Name[zh_CN]=打开方式
Name[zh_TW]=開啟方式
GenericName=Open With
GenericName[bg]=Отваряне с
GenericName[bs]=Otvori pomoću
GenericName[ca]=Obre amb
GenericName[ca@valencia]=Obri amb
GenericName[cs]=Otevřít pomocí
GenericName[da]=Åbn med
GenericName[de]=Öffnen mit
GenericName[el]=Άνοιγμα με
GenericName[en_GB]=Open With
GenericName[es]=Abrir con
GenericName[et]=Avamine rakendusega
GenericName[fi]=Avaa ohjelmalla
GenericName[fr]=Ouvrir avec
GenericName[gl]=Abrir con
GenericName[hu]=Megnyitás ezzel
GenericName[it]=Apri con
GenericName[ja]=アプリケーションで開く
GenericName[kk]=Мынамен ашу
GenericName[mr]=यामध्ये उघडा
GenericName[nb]=Åpne med
GenericName[nds]=Opmaken mit
GenericName[nl]=Openen met
GenericName[pl]=Otwórz za pomocą
GenericName[pt]=Abrir Com
GenericName[pt_BR]=Abrir com
GenericName[ru]=Открыть с помощью
GenericName[sk]=Otvoriť s
GenericName[sl]=Odpri z
GenericName[sv]=Öppna med
GenericName[tr]=Birlikte Aç
GenericName[ug]=بۇنىڭدا ئېچىش
GenericName[uk]=Відкриття у зовнішніх програмах
GenericName[x-test]=xxOpen Withxx
GenericName[zh_CN]=打开方式
GenericName[zh_TW]=開啟方式
ServiceTypes=KDevelop/Plugin
X-KDE-Library=kdevopenwith
X-KDevelop-Version=@KDEV_PLUGIN_VERSION@
X-KDevelop-Category=Global
X-KDE-PluginInfo-Name=kdevopenwith
X-KDE-PluginInfo-Author=Andreas Pakulat
X-KDevelop-Interfaces=org.kdevelop.IOpenWith
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-Category=Core
X-KDevelop-Mode=GUI
